@@ -1,10 +1,13 @@
 from .util.backend_functions import get_backend, set_backend
 from .util.backend_functions import backend as bd
+from .util.backend_functions import backend as bd
+from .util.image_handling import load_image_as_function
+from .util.file_handling import load_file_as_function, load_phase_as_function
 from .polychromatic_simulator import PolychromaticField
 from .monochromatic_simulator import MonochromaticField
 from . import colour_functions as cf
 from .polynomials import zernike_polynomial
-from .holography import FourierPhaseRetrieval, CustomPhaseRetrieval
+from .holography import FourierPhaseRetrieval, CustomPhaseRetrieval, RotationalPhaseDesign
 from .diffractive_elements import *
 from .light_sources import *
 
