@@ -12,13 +12,17 @@ All rights reserved.
 
 """
 
-def plot_longitudinal_profile_colors(self, longitudinal_profile_rgb, start_distance, end_distance, xlim=None, ylim=None, units = mm):
+def plot_longitudinal_profile_colors(self, longitudinal_profile_rgb, extent, xlim=None, ylim=None, units = mm,  z_units = cm, dark_background = False):
     """visualize the diffraction pattern longitudinal profile colors with matplotlib"""
 
     from ..util.backend_functions import backend as bd
-    plt.style.use("dark_background")
+    from ..util.backend_functions import backend_name
+    if dark_background == True:
+        plt.style.use("dark_background")
+    else:
+        plt.style.use("default")
 
-    if bd != np:
+    if backend_name == 'cupy':
         longitudinal_profile_rgb = longitudinal_profile_rgb.transpose(1,0,2).get()
     else:
         longitudinal_profile_rgb = longitudinal_profile_rgb.transpose(1,0,2)
@@ -26,14 +30,15 @@ def plot_longitudinal_profile_colors(self, longitudinal_profile_rgb, start_dista
     fig = plt.figure(figsize=(16/9 *6,6)) 
     ax = fig.add_subplot(1,1,1)  
         
-    ax.set_xlabel('Screen Distance [cm]')
     ax.set_title("Longitudinal Profile")
     
     if xlim != None:
-        ax.set_xlim(np.array(xlim)/cm)
+        ax.set_xlim(np.array(xlim)/z_units)
     if ylim != None:
         ax.set_ylim(np.array(ylim)/units)
 
+
+
     if units == mm:
         ax.set_ylabel("[mm]")
     elif units == um:
@@ -45,27 +50,48 @@ def plot_longitudinal_profile_colors(self, longitudinal_profile_rgb, start_dista
     elif units == m:
         ax.set_ylabel("[m]")
 
-    im = ax.imshow(longitudinal_profile_rgb,  extent = [start_distance/cm,  end_distance/cm, float(self.x[0]) / units, float(self.x[-1] + self.dx) / units],  interpolation='spline36', aspect = 'auto')
+
+
+    if z_units == mm:
+        ax.set_xlabel('Screen Distance [mm]')
+    elif z_units == um:
+        ax.set_xlabel('Screen Distance [um]')
+    elif z_units == cm:
+        ax.set_xlabel('Screen Distance [cm]')
+    elif z_units == nm:
+        ax.set_xlabel('Screen Distance [nm]')
+    elif z_units == m:
+        ax.set_xlabel('Screen Distance [m]')
+
+
+    dz = (extent[3] - extent[2])/ longitudinal_profile_rgb.shape[1]
+
+    im = ax.imshow(longitudinal_profile_rgb,  extent = [(extent[2]- dz/2)/z_units ,  (extent[3]+ dz/2)/z_units, float(extent[0]- self.dx/2) / units, float(extent[1]+ self.dx/2) / units],  interpolation='spline36', aspect = 'auto')
     plt.show()
 
 
-def plot_longitudinal_profile_intensity(self,  longitudinal_profile_E, start_distance, end_distance, square_root = False, grid = False, xlim=None, ylim=None, units = mm):
+def plot_longitudinal_profile_intensity(self,  longitudinal_profile_E, extent,  square_root = False, grid = False, xlim=None, ylim=None, units = mm,  z_units = cm, dark_background = False):
     """visualize the diffraction pattern longitudinal profile intensity with matplotlib"""
 
     from ..util.backend_functions import backend as bd
-    plt.style.use("dark_background")
+    from ..util.backend_functions import backend_name
+
+    if dark_background == True:
+        plt.style.use("dark_background")
+    else:
+        plt.style.use("default")
 
     I = bd.real(longitudinal_profile_E*np.conjugate(longitudinal_profile_E))
     I = I.transpose(1,0)
 
     if square_root == False:
-        if bd != np:
+        if backend_name == 'cupy':
             I = I.get()
         else:
             I = I
 
     else:
-        if bd != np:
+        if backend_name == 'cupy':
             I = np.sqrt(I.get())
         else:
             I = np.sqrt(I)
@@ -93,15 +119,25 @@ def plot_longitudinal_profile_intensity(self,  longitudinal_profile_E, start_dis
 
 
 
+    if z_units == mm:
+        ax.set_xlabel('Screen Distance [mm]')
+    elif z_units == um:
+        ax.set_xlabel('Screen Distance [um]')
+    elif z_units == cm:
+        ax.set_xlabel('Screen Distance [cm]')
+    elif z_units == nm:
+        ax.set_xlabel('Screen Distance [nm]')
+    elif z_units == m:
+        ax.set_xlabel('Screen Distance [m]')
+
 
 
-    
-    ax.set_xlabel('Screen Distance [cm]')
     ax.set_title("Longitudinal Profile")
     if grid == True:
         ax.grid(alpha =0.2)
 
-    im = ax.imshow(I, cmap= 'inferno',  extent = [start_distance/cm,  end_distance/cm, float(self.x[0]) / units, float(self.x[-1]+ self.dx) / units],  interpolation='spline36', aspect = 'auto')
+    dz = (extent[3] - extent[2])/ I.shape[1]
+    im = ax.imshow(I, cmap= 'inferno',  extent = [(extent[2]- dz/2)/z_units ,  (extent[3]+ dz/2)/z_units, float(extent[0]- self.dx/2) / units, float(extent[1]+ self.dx/2) / units],  interpolation='spline36', aspect = 'auto')
     
     cb = fig.colorbar(im, orientation = 'vertical')
 
